@@ -10,30 +10,36 @@ from sqlalchemy.orm import sessionmaker, mapper
 from cap.cap_config import CAPStorageConfig
 
 metadata = MetaData()
-message_published_table = Table("Published", metadata,
-                                Column("Id", Integer, primary_key=True, autoincrement=False),
-                                Column("Version", String, default="V1"),
-                                Column("Name", String),
-                                Column("Content", String),
-                                Column("Retries", Integer, default=0),
-                                Column("Added", DateTime),
-                                Column("ExpiresAt", DateTime),
-                                Column("StatusName", String),
-                                schema="[cap]")
 
 
+@mapper_registry.mapped
+@dataclass
 class MessagePublished:
     """
-    消息发布表实体
+    Published
     """
 
-    def __init__(self, id, name, content, added, expires_at, status_name):
-        self.Id = id
-        self.Name = name
-        self.Content = content
-        self.Added = added
-        self.ExpiresAt = expires_at
-        self.StatusName = status_name
+    __table__ = Table(
+        "Published",
+        mapper_registry.metadata,
+        Column("Id", Integer, primary_key=True, autoincrement=False),
+        Column("Version", String, default="V1"),
+        Column("Name", String),
+        Column("Content", String),
+        Column("Retries", Integer, default=0),
+        Column("Added", DateTime),
+        Column("ExpiresAt", DateTime),
+        Column("StatusName", String),
+        schema="[cap]"
+    )
+    Id: int = field(init=False)
+    Version: str = None
+    Name: str = None
+    Content: str = None
+    Retries: Integer = None
+    Added: DateTime = None
+    ExpiresAt: DateTime = None
+    StatusName: String = None
 
 
 class CAPStorageBase(object):
@@ -45,10 +51,6 @@ class CAPStorageBase(object):
         pass
 
 
-# 通过mapper函数进行映射关联
-mapper(MessagePublished, message_published_table)
-
-
 class CAPStorage(CAPStorageBase):
     """
     CAP消息存储
@@ -72,9 +74,13 @@ class CAPStorage(CAPStorageBase):
 
             with session_cls() as session:
 
-                message_published = MessagePublished(message_id, routing_key, message,
-                                                     str(datetime.utcnow()), str(datetime.utcnow()),
-                                                     status)
+                message_published = MessagePublished()
+                message_published.Id = message_id
+                message_published.Name = routing_key
+                message_published.Content = message
+                message_published.Added = str(datetime.now())
+                message_published.ExpiresAt = str(datetime.now()+datetime.timedelta(days=1))
+                message_published.StatusName = status
                 session.add(message_published)
 
                 # 提交即保存到数据库:
